Compute the conditional Aalen-Johansen estimator.
aalen_johansen(
data,
x = NULL,
a = NULL,
p = NULL,
alpha = 0.05,
collapse = FALSE
)A list containing the Aalen-Johansen estimator, the Nelson-Aalen estimator, and related quantities.
A list of trajectory data for each individual.
A numeric value for conditioning.
A bandwidth. Default uses an asymmetric version using alpha.
An integer representing the number of states. The absorbing state is last.
A probability around the point x, for asymmetric sub-sampling.
Logical, whether to collapse the last state of the model.